elephant.conversion.BinnedSpikeTrainView
========================================

.. currentmodule:: elephant.conversion

.. autoclass:: BinnedSpikeTrainView
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BinnedSpikeTrainView.__init__
      ~BinnedSpikeTrainView.binarize
      ~BinnedSpikeTrainView.copy
      ~BinnedSpikeTrainView.get_num_of_spikes
      ~BinnedSpikeTrainView.rescale
      ~BinnedSpikeTrainView.time_slice
      ~BinnedSpikeTrainView.to_array
      ~BinnedSpikeTrainView.to_bool_array
      ~BinnedSpikeTrainView.to_sparse_array
      ~BinnedSpikeTrainView.to_sparse_bool_array
      ~BinnedSpikeTrainView.to_spike_trains
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BinnedSpikeTrainView.bin_centers
      ~BinnedSpikeTrainView.bin_edges
      ~BinnedSpikeTrainView.bin_size
      ~BinnedSpikeTrainView.binsize
      ~BinnedSpikeTrainView.is_binary
      ~BinnedSpikeTrainView.num_bins
      ~BinnedSpikeTrainView.shape
      ~BinnedSpikeTrainView.sparsity
      ~BinnedSpikeTrainView.spike_indices
      ~BinnedSpikeTrainView.t_start
      ~BinnedSpikeTrainView.t_stop
   
   